==> google-cloud-monitoring-2.4.1.tar.gz: google-cloud-monitoring-2.4.1/google/cloud/monitoring_v3/services/query_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterable,
    Awaitable,
    Callable,
    Iterable,
    Sequence,
    Tuple,
    Optional,
)

from google.cloud.monitoring_v3.types import metric
from google.cloud.monitoring_v3.types import metric_service


class QueryTimeSeriesPager:
    """A pager for iterating through ``query_time_series`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``time_series_data`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``QueryTimeSeries`` requests and continue to iterate
    through the ``time_series_data`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., metric_service.QueryTimeSeriesResponse],
        request: metric_service.QueryTimeSeriesRequest,
        response: metric_service.QueryTimeSeriesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.monitoring_v3.types.QueryTimeSeriesRequest):
                The initial request object.
            response (google.cloud.monitoring_v3.types.QueryTimeSeriesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = metric_service.QueryTimeSeriesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[metric_service.QueryTimeSeriesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[metric.TimeSeriesData]:
        for page in self.pages:
            yield from page.time_series_data

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class QueryTimeSeriesAsyncPager:
    """A pager for iterating through ``query_time_series`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``time_series_data`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``QueryTimeSeries`` requests and continue to iterate
    through the ``time_series_data`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[metric_service.QueryTimeSeriesResponse]],
        request: metric_service.QueryTimeSeriesRequest,
        response: metric_service.QueryTimeSeriesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.monitoring_v3.types.QueryTimeSeriesRequest):
                The initial request object.
            response (google.cloud.monitoring_v3.types.QueryTimeSeriesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = metric_service.QueryTimeSeriesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[metric_service.QueryTimeSeriesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[metric.TimeSeriesData]:
        async def async_generator():
            async for page in self.pages:
                for response in page.time_series_data:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google-cloud-monitoring-2.14.2.tar.gz: google-cloud-monitoring-2.14.2/google/cloud/monitoring_v3/services/query_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.monitoring_v3.types import metric
from google.cloud.monitoring_v3.types import metric_service


class QueryTimeSeriesPager:
    """A pager for iterating through ``query_time_series`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``time_series_data`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``QueryTimeSeries`` requests and continue to iterate
    through the ``time_series_data`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., metric_service.QueryTimeSeriesResponse],
        request: metric_service.QueryTimeSeriesRequest,
        response: metric_service.QueryTimeSeriesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.monitoring_v3.types.QueryTimeSeriesRequest):
                The initial request object.
            response (google.cloud.monitoring_v3.types.QueryTimeSeriesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = metric_service.QueryTimeSeriesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[metric_service.QueryTimeSeriesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[metric.TimeSeriesData]:
        for page in self.pages:
            yield from page.time_series_data

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class QueryTimeSeriesAsyncPager:
    """A pager for iterating through ``query_time_series`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``time_series_data`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``QueryTimeSeries`` requests and continue to iterate
    through the ``time_series_data`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.monitoring_v3.types.QueryTimeSeriesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[metric_service.QueryTimeSeriesResponse]],
        request: metric_service.QueryTimeSeriesRequest,
        response: metric_service.QueryTimeSeriesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.monitoring_v3.types.QueryTimeSeriesRequest):
                The initial request object.
            response (google.cloud.monitoring_v3.types.QueryTimeSeriesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = metric_service.QueryTimeSeriesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[metric_service.QueryTimeSeriesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[metric.TimeSeriesData]:
        async def async_generator():
            async for page in self.pages:
                for response in page.time_series_data:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
